@@ -20,7 +20,7 @@ __PACKAGE__->mk_accessors(
                           qw( main_dir debian_dir bins control pkgname homepage elpa_version copyright gpl_version )
                          );
 
-use constant debstdversion => '4.1.3';
+use constant debstdversion => '3.9.8';
 
 sub extract_basic {
     my $self = shift;
@@ -165,11 +165,11 @@ sub fill_vcs {
 
     if ( $self->cfg->pkg_emacsen ) {
         $src->Vcs_Git(
-                      sprintf( "https://salsa.debian.org/emacsen-team/%s.git/",
+                      sprintf( "https://anonscm.debian.org/git/pkg-emacsen/pkg/%s.git",
                                $self->pkgname )
                      );
         $src->Vcs_Browser(
-                          sprintf( "https://salsa.debian.org/emacsen-team/%s",
+                          sprintf( "https://anonscm.debian.org/cgit/pkg-emacsen/pkg/%s.git/",
                                    $self->pkgname )
                          );
     }
