@@ -88,7 +88,7 @@ sub create_control {
                        Architecture      => "all",
                        Depends           => "$depends",
                        Recommends        => "emacs (>= 46.0)",
-                       Enhances          => "emacs, emacs25",
+                       Enhances          => "emacs, emacs24, emacs25",
                        short_description => "$short_desc",
                        long_description  => "$long_desc",
                      };
